==> subtitleeditor_0.52.1.orig.tar.gz: subtitleeditor-0.52.1/plugins/actions/errorchecking/mindisplaytime.h <==
#ifndef _MinDisplayTime_h
#define _MinDisplayTime_h

/*
 *	subtitleeditor -- a tool to create or edit subtitle
 *
 *	http://home.gna.org/subtitleeditor/
 *	https://gna.org/projects/subtitleeditor/
 *
 *	Copyright @ 2005-2015, kitone
 *
 *	This program is free software; you can redistribute it and/or modify
 *	it under the terms of the GNU General Public License as published by
 *	the Free Software Foundation; either version 3 of the License, or
 *	(at your option) any later version.
 *
 *	This program is distributed in the hope that it will be useful,
 *	but WITHOUT ANY WARRANTY; without even the implied warranty of
 *	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *	GNU General Public License for more details.
 *
 *	You should have received a copy of the GNU General Public License
 *	along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

#include "errorchecking.h"

/*
 *
 */
class MinDisplayTime : public ErrorChecking
{
public:

	MinDisplayTime()
	:ErrorChecking(
			"min-display-time",
			_("Minimum Display Time"),
			_("Detects and fixes subtitles when the duration is inferior to the specified value."))
	{
		m_min_display = 1000; // a second
	}
	
	/*
	 *
	 */
	virtual void init()
	{
		m_min_display = Config::getInstance().get_value_int("timing", "min-display");
	}

	/*
	 *
	 */
	bool execute(Info &info)	
	{
		SubtitleTime duration = info.currentSub.get_duration();

		if(duration.totalmsecs >= m_min_display)
			return false;

		SubtitleTime new_end = info.currentSub.get_start() + SubtitleTime(m_min_display);

		if(info.tryToFix)
		{
			info.currentSub.set_end(new_end);
			return true;
		}

		info.error = build_message(
				_("Subtitle display time is too short: <b>%s</b>"), 
				duration.str().c_str());

		info.solution = build_message(
				_("<b>Automatic correction:</b> to change current subtitle end to %s."),
				new_end.str().c_str());

		return true;
	}

protected:
	int m_min_display;
};

#endif//_MinDisplayTime_h

==> subtitleeditor_0.54.0.orig.tar.gz: subtitleeditor-0.54.0/plugins/actions/errorchecking/mindisplaytime.h <==
#ifndef _MinDisplayTime_h
#define _MinDisplayTime_h

/*
 *	subtitleeditor -- a tool to create or edit subtitle
 *
 *	https://kitone.github.io/subtitleeditor/
 *	https://github.com/kitone/subtitleeditor/
 *
 *	Copyright @ 2005-2015, kitone
 *
 *	This program is free software; you can redistribute it and/or modify
 *	it under the terms of the GNU General Public License as published by
 *	the Free Software Foundation; either version 3 of the License, or
 *	(at your option) any later version.
 *
 *	This program is distributed in the hope that it will be useful,
 *	but WITHOUT ANY WARRANTY; without even the implied warranty of
 *	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *	GNU General Public License for more details.
 *
 *	You should have received a copy of the GNU General Public License
 *	along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

#include "errorchecking.h"

/*
 *
 */
class MinDisplayTime : public ErrorChecking
{
public:

	MinDisplayTime()
	:ErrorChecking(
			"min-display-time",
			_("Minimum Display Time"),
			_("Detects and fixes subtitles when the duration is inferior to the specified value."))
	{
		m_min_display = 1000; // a second
	}
	
	/*
	 *
	 */
	virtual void init()
	{
		m_min_display = Config::getInstance().get_value_int("timing", "min-display");
	}

	/*
	 *
	 */
	bool execute(Info &info)	
	{
		SubtitleTime duration = info.currentSub.get_duration();

		if(duration.totalmsecs >= m_min_display)
			return false;

		SubtitleTime new_end = info.currentSub.get_start() + SubtitleTime(m_min_display);

		if(info.tryToFix)
		{
			info.currentSub.set_end(new_end);
			return true;
		}

		info.error = build_message(
				_("Subtitle display time is too short: <b>%s</b>"), 
				duration.str().c_str());

		info.solution = build_message(
				_("<b>Automatic correction:</b> to change current subtitle end to %s."),
				new_end.str().c_str());

		return true;
	}

protected:
	int m_min_display;
};

#endif//_MinDisplayTime_h
